@@ -12,6 +12,8 @@ import numpy as np
 from scipy import signal, integrate
 from scipy.interpolate import interp1d
 import math
+from statsmodels.tools.sm_exceptions import MissingDataError
+from numpy.linalg import LinAlgError
 
 
 def set_property(key, value):
